@@ -110,6 +110,7 @@ impl Cmd {
     }
 }
 
+#[allow(clippy::fallible_impl_from)]
 impl From<Cmd> for cm::MetadataCommand {
     fn from(mut cmd: Cmd) -> cm::MetadataCommand {
         let mut mdc = cm::MetadataCommand::new();
@@ -178,8 +179,9 @@ impl From<Cmd> for cm::MetadataCommand {
     }
 }
 
+#[derive(Clone)]
 pub enum Target {
-    Builtin(&'static cfg_expr::targets::TargetInfo<'static>),
+    Builtin(&'static cfg_expr::targets::TargetInfo),
     #[cfg(feature = "targets")]
     Triple(cfg_expr::target_lexicon::Triple),
     Unknown(String),
@@ -209,6 +211,19 @@ where
     }
 }
 
+use std::fmt;
+
+impl fmt::Display for Target {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            Self::Builtin(bi) => f.write_str(bi.triple.as_str()),
+            #[cfg(feature = "targets")]
+            Self::Triple(trip) => write!(f, "{}", trip),
+            Self::Unknown(unknown) => f.write_str(unknown),
+        }
+    }
+}
+
 struct TargetFilter {
     inner: Target,
     features: Vec<String>,
@@ -238,7 +253,7 @@ impl TargetFilter {
 
     fn matches_triple(&self, triple: &str) -> bool {
         match &self.inner {
-            Target::Builtin(bi) => bi.triple == triple,
+            Target::Builtin(bi) => bi.triple.as_str() == triple,
             #[cfg(feature = "targets")]
             Target::Triple(trip) => {
                 let as_triple = format!("{}", trip);
@@ -278,7 +293,7 @@ where
     F: FnMut(cm::Package),
 {
     fn filtered(&mut self, krate: cm::Package) {
-        self(krate)
+        self(krate);
     }
 }
 
@@ -771,7 +786,7 @@ impl Builder {
                                     return Some((
                                         Edge {
                                             kind: dk.kind,
-                                            cfg: Some(cfg.to_owned()),
+                                            cfg: Some(cfg.clone()),
                                         },
                                         &rdep.pkg,
                                     ));
@@ -806,7 +821,7 @@ impl Builder {
                                     Some((
                                         Edge {
                                             kind: dk.kind,
-                                            cfg: Some(cfg.to_owned()),
+                                            cfg: Some(cfg.clone()),
                                         },
                                         &rdep.pkg,
                                     ))
